# Python-Outbox

Python-outbox is a library that implement the Outbox pattern.

It try to separate concerns of retrieving and publishing events in the pattern, allowing a generic implementation for any use case you would want.